aboutsummaryrefslogtreecommitdiff
path: root/ext/js/comm/api.js
diff options
context:
space:
mode:
authorEloy Robillard <eloy.robillard@gmail.com>2024-02-15 04:02:36 +0100
committerGitHub <noreply@github.com>2024-02-15 03:02:36 +0000
commit7a4096240ce4faf70a785d047945388baa0daab3 (patch)
tree841da38533391a095fdb932c528c4b5c3366ba1b /ext/js/comm/api.js
parent043ac79203abbc9c7f3aa971e2de8ddedb3c0e90 (diff)
Show all duplicate notes on click (#636)
* Show all duplicate notes on click * Change 'notesView' to 'viewNotes' * Replace api.noteView with api.viewNotes * Update "viewNote" action to "viewNotes" in options util * Update options-util test with "viewNotes" action * Replace uses of "viewNote" with "viewNotes" * Replace _viewNote with _viewNotes * Rename /*ViewNote*/ methods to /*ViewNotes*/
Diffstat (limited to 'ext/js/comm/api.js')
-rw-r--r--ext/js/comm/api.js12
1 files changed, 6 insertions, 6 deletions
diff --git a/ext/js/comm/api.js b/ext/js/comm/api.js
index 2e1e8826..b4fdbeb5 100644
--- a/ext/js/comm/api.js
+++ b/ext/js/comm/api.js
@@ -118,13 +118,13 @@ export class API {
}
/**
* @param {import('api').ApiParam<'noteView', 'noteId'>} noteId
* @param {import('api').ApiParam<'noteView', 'mode'>} mode
* @param {import('api').ApiParam<'noteView', 'allowFallback'>} allowFallback
* @returns {Promise<import('api').ApiReturn<'noteView'>>}
*/
- noteView(noteId, mode, allowFallback) {
- return this._invoke('noteView', {noteId, mode, allowFallback});
+ viewNotes(noteIds, mode, allowFallback) {
+ return this._invoke('viewNotes', {noteIds, mode, allowFallback});
}
/**
@@ -118,13 +118,13 @@ export class API {
}
/**
- * @param {import('api').ApiParam<'noteView', 'noteId'>} noteId
- * @param {import('api').ApiParam<'noteView', 'mode'>} mode
- * @param {import('api').ApiParam<'noteView', 'allowFallback'>} allowFallback
- * @returns {Promise<import('api').ApiReturn<'noteView'>>}
+ * @param {import('api').ApiParam<'viewNotes', 'noteIds'>} noteIds
+ * @param {import('api').ApiParam<'viewNotes', 'mode'>} mode
+ * @param {import('api').ApiParam<'viewNotes', 'allowFallback'>} allowFallback
+ * @returns {Promise<import('api').ApiReturn<'viewNotes'>>}
*/